from importlib.machinery import SourceFileLoader

from setuptools import setup

version = SourceFileLoader('version', 'hub/version.py').load_module()

install_requirements = [
    'boto3>=1.9.84,<2.0',
    'jsonpickle',
    'timeout-decorator>=0.4.1,<0.5',
]

test_requires = [
    'pytest',
    'pytest-cov',
    'black',
    'isort[pipfile]',
    'flake8',
    'moto==1.3.13',
    'jsonpickle',
]

with open('README.md', 'r') as f:
    long_description = f.read()

setup(
    name='hub-kinesis',
    version=version.__version__,
    author='Cuenca',
    author_email='dev@cuenca.com',
    description='Library for Kinesis Implementation',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/cuenca-mx/hub',
    packages=['hub'],
    python_requires='>=3.6',
    install_requires=install_requirements,
    setup_requires=['pytest-runner'],
    tests_require=test_requires,
    extras_require=dict(test=test_requires),
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)



import os

import boto3

ACCESS_KEY = os.environ['ACCESS_KEY']
SECRET_KEY = os.environ['SECRET_KEY']
REGION_NAME = os.environ['REGION_NAME']

kinesis_client = boto3.client(
    'kinesis',
    region_name=REGION_NAME,
    aws_access_key_id=ACCESS_KEY,
    aws_secret_access_key=SECRET_KEY,
)

dynamo_client = boto3.client(
    'dynamodb',
    region_name=REGION_NAME,
    aws_access_key_id=ACCESS_KEY,
    aws_secret_access_key=SECRET_KEY,
)
